/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.mda.config;

import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
/**
 * 排序字段
 * fielduuid属性为排序字段对当前模型字段的引用
 * 该字段必有值
 * modeluuid
 * 该属性在实体模型中无效
 * 在视图模型中
 * 为空，则fielduuid为当前视图模型字段
 * 不为空，则fielduuid为modeluuid所指向的模型的字段的uuid
 * @author chenjiao
 *
 */
@XStreamAlias("order-field")
public class OrderField {
	//引用的模型(或视图)字段id
	//必不为空
	@XStreamAsAttribute
	@XStreamAlias("field-uuid")
	String fielduuid;
	
	//modeluuid为relatemodel的uuid
	//可为空
	//在实体模型中必为空
	//在视图模型中，若为空，则fielduuid为视图模型字段
	//若不为空，则fielduuid为此字段所指向模型的字段uuid
	@XStreamAsAttribute
	@XStreamAlias("model-uuid")
	String modeluuid;
	
	
	@XStreamAsAttribute
	@XStreamAlias("order-mode")
	String orderMode;// 如果是固定值，则这里有值[desc/asc]，否则为传入值，如果没有传入值，则忽略之
	//是否可编辑
	@XStreamAsAttribute
	boolean editable;
	//是否隐藏
	@XStreamAsAttribute
	boolean hidden;
	//展现方式
	
	public String getOrderMode() {
		return orderMode;
	}
	public String getFielduuid() {
		return fielduuid;
	}
	public void setFielduuid(String fielduuid) {
		this.fielduuid = fielduuid;
	}
	public void setOrderMode(String orderMode) {
		this.orderMode = orderMode;
	}
	public boolean isEditable() {
		return editable;
	}
	public void setEditable(boolean editable) {
		this.editable = editable;
	}
	public boolean isHidden() {
		return hidden;
	}
	public void setHidden(boolean hidden) {
		this.hidden = hidden;
	}
	public String getModeluuid() {
		return modeluuid;
	}
	public void setModeluuid(String modeluuid) {
		this.modeluuid = modeluuid;
	}
	
	
	
}
