/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.mda.config.entity;

import java.util.ArrayList;
import java.util.List;

import org.tinygroup.mda.ValidateRule;

import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;

/**
 * 模型的属性
 * @author luoguo
 *
 */
@XStreamAlias("entity-field")
public class EntityField {
	
	/**
	 * 标准字段名
	 */
	@XStreamAsAttribute
	@XStreamAlias("standard-field")
	private String standardFieldId;
	/**
	 * 是否主键
	 */
	@XStreamAsAttribute
	private boolean primary;
	/**
	 * 是否唯一
	 */
	@XStreamAsAttribute
	private boolean unique;
	/**
	 * 是否显示字段
	 */
	@XStreamAsAttribute
	private boolean display;
	/**
	 * 输入方式，每种方式可以有自己的属性，目前是该输入模式处理器的beanid
	 */
	@XStreamAsAttribute
	@XStreamAlias("input-mode")
	private String inputMode; 
	/**
	 * 验证规则，这个和校验框架对接，每种方式可以有种的属性
	 */
	@XStreamAlias("validate-rules")
	private List<ValidateRule> validateRules; 
	/**
	 * 实体名称，如果存在，就表示是一个对象引用
	 */
	@XStreamAsAttribute
	@XStreamAlias("entity-uuid")
	private String entityuuid; 
	/**
	 * 唯一决定一个字段
	 */
	@XStreamAsAttribute
	private String uuid;
	
	

	public String getEntityuuid() {
		return entityuuid;
	}

	public void setEntityuuid(String entityuuid) {
		this.entityuuid = entityuuid;
	}

	public String getUuid() {
		return uuid;
	}

	public void setUuid(String uuid) {
		this.uuid = uuid;
	}

	

	public String getStandardFieldId() {
		return standardFieldId;
	}

	public void setStandardFieldId(String standardFieldId) {
		this.standardFieldId = standardFieldId;
	}

	public boolean isPrimary() {
		return primary;
	}

	public void setPrimary(boolean primary) {
		this.primary = primary;
	}

	public boolean isUnique() {
		return unique;
	}

	public void setUnique(boolean unique) {
		this.unique = unique;
	}

	public boolean isDisplay() {
		return display;
	}

	public void setDisplay(boolean display) {
		this.display = display;
	}

	public String getInputMode() {
		return inputMode;
	}

	public void setInputMode(String inputMode) {
		this.inputMode = inputMode;
	}

	public List<ValidateRule> getValidateRules() {
		if(validateRules==null)
			validateRules = new ArrayList<ValidateRule>();
		return validateRules;
	}

	public void setValidateRules(List<ValidateRule> validateRules) {
		this.validateRules = validateRules;
	}

}
