/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.mda.impl;

import java.util.ArrayList;
import java.util.List;

import org.tinygroup.mda.ModelManager;
import org.tinygroup.mda.config.entity.EntityModel;
import org.tinygroup.mda.config.view.ViewModel;

public class ModelManagerImpl implements ModelManager {

	private List<EntityModel> entitys = new ArrayList<EntityModel>();
	private List<ViewModel> viewModels = new ArrayList<ViewModel>();

	public void addViewModel(ViewModel model) {
		viewModels.add(model);
	}

	public void addEntityModel(EntityModel model) {
		entitys.add(model);
	}

	public ViewModel getViewModel(String uuid) {
		for (ViewModel model : viewModels) {
			if (model.getUuid().equals(uuid))
				return model;
		}
		throw new RuntimeException(String.format("找不到视图模型,uuid:%s", uuid));
	}

	public EntityModel getEntityModel(String uuid) {
		for (EntityModel model : entitys) {
			if (model.getUuid().equals(uuid))
				return model;
		}
		throw new RuntimeException(String.format("找不到实体模型,uuid:%s", uuid));
	}

	public EntityModel getEntityModelByName(String name) {
		for (EntityModel model : entitys) {
			if (model.getName().equals(name))
				return model;
		}
		throw new RuntimeException(String.format("找不到实体模型,name:%s", name));
	}

	public ViewModel getViewModelByName(String name) {
		for (ViewModel model : viewModels) {
			if (model.getName().equals(name))
				return model;
		}
		throw new RuntimeException(String.format("找不到视图模型,name:%s", name));
	}

	public List<EntityModel> getEntityModels() {
		return entitys;
	}

	public List<ViewModel> getViewModels() {
		return viewModels;
	}

}
