/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.mda.javabean.impl;

import java.util.Map;

import org.tinygroup.context.Context;
import org.tinygroup.context.impl.ContextImpl;
import org.tinygroup.mda.config.entity.EntityModel;
import org.tinygroup.mda.config.trans.MDACreatorConfig;
import org.tinygroup.mda.config.trans.MDACreators;
import org.tinygroup.mda.javabean.BeanDetial;
import org.tinygroup.mda.javabean.BeanProperty;
import org.tinygroup.mda.javabean.JavaFileCreatorHelper;
import org.tinygroup.mda.transform.entity.EntityModelTransformer;
import org.tinygroup.mda.util.FileUtil;
import org.tinygroup.mda.util.MDANameUtil;
import org.tinygroup.mda.util.ModelTransUtil;
import org.tinygroup.mda.util.RandomUtil;

public abstract class EntityJavaFileVelocityCreatorHelper extends
		MDATemplateHelper implements JavaFileCreatorHelper {
	protected Context context;
	protected Map<String, String> creatorsConfig;

	public void setCreatorConfig(MDACreatorConfig creator, MDACreators creators) {
		setTemplateMap(ModelTransUtil.getTemplateMap(creator));
		creatorsConfig = creators.getPropertys();
	}

	/**
	 * 获取bean对应对象的key的数据类型
	 * 
	 * @param detial
	 * @return
	 */
	private BeanProperty getPrimary(BeanDetial detial) {
		for (BeanProperty property : detial.getProperties()) {
			if (property.isPrimary())
				return property;
		}
		throw new RuntimeException("主键不存在！");
	}

	private Context getContext(EntityModel model, BeanDetial beanDetial) {
		Context context = new ContextImpl();
		String beanPackageName = "";
		if (beanDetial.getPackageName() != null) {
			beanPackageName = beanDetial.getPackageName()+".pojo";
		}
		String tablepre = "";
		if (creatorsConfig != null)
			tablepre = creatorsConfig.get(EntityModelTransformer.TABLE_PRE);
		String tableName = MDANameUtil.getTableName(model, tablepre);
		String daoName = MDANameUtil.getDaoName(beanDetial.getName()); // 首字母大写的
		String daoPackageName = MDANameUtil.getDaoPackage(beanDetial
				.getPackageName());
		String primaryType = getPrimary(beanDetial).getJavaType();
		// bean相关属性
		context.put("bean", beanDetial);
		context.put("beanPackageName", beanPackageName);
		context.put("tableName", tableName);
		//context.put("beanFullName", beanDetial.getFullName());
		context.put("beanFullName", MDANameUtil.getBeanFullName(beanDetial));
		context.put("MDANameUtil", new MDANameUtil());
		context.put("model", model);
		context.put("primaryType", primaryType);
		context.put("beanVarName", MDANameUtil.getMDAName(beanDetial.getName()));
		// dao相关属性
		context.put(DAO_NAME, daoName);
		context.put(DAO_PACKAGE_NAME, daoPackageName);
		// logic相关
		context.put(LOGIC_NAME, MDANameUtil.getLogicName(model.getName()));
		context.put(LOGIC_PACKAGE_NAME,
				MDANameUtil.getLogicPackage(model.getPackageName()));
		context.put(LOGIC_INTERFACE_NAME,
				MDANameUtil.getLogicInterfaceName(model.getName()));
		context.put(LOGIC_INTERFACE_PACKAGE_NAME,
				MDANameUtil.getLogicInterfacePackage(model.getPackageName()));
		// service相关
		context.put(SERVICE_NAME, MDANameUtil.getServiceName(model.getName()));
		context.put(SERVICE_PACKAGE_NAME,
				MDANameUtil.getServicePackage(model.getPackageName()));
		context.put(SERVICE_INTERFACE_NAME,
				MDANameUtil.getServiceInterfaceName(model.getName()));
		context.put(SERVICE_INTERFACE_PACKAGE_NAME,
				MDANameUtil.getServiceInterfacePackage(model.getPackageName()));
		// springbeans相关
		context.put(SERVICE_BEAN_ID,
				MDANameUtil.getBizServiceBeanId(model.getName()));
		context.put(LOGIC_BEAN_ID, MDANameUtil.getLogicBeanId(model.getName()));
		context.put(DAO_BEAN_ID, MDANameUtil.getDaoBeanId(model.getName()));
		// seriziable 随机值
		context.put("RandomUtil",new RandomUtil());
		return context;
	}

	public void createFile(EntityModel model, BeanDetial beanDetial,
			FileUtil fileUtil) {
		context = getContext(model, beanDetial);
		doCreateFile(model, beanDetial, fileUtil);
	}

	protected abstract void doCreateFile(EntityModel model,
			BeanDetial beanDetial, FileUtil fileUtil);
}
