/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.mda.javabean.impl;


import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;
import org.tinygroup.mda.MDAFileCreator;
import org.tinygroup.mda.config.entity.EntityModel;
import org.tinygroup.mda.javabean.BeanDetial;
import org.tinygroup.mda.javabean.JavaFileCreatorHelper;
import org.tinygroup.mda.util.FileUtil;
import org.tinygroup.mda.util.ModelTransUtil;

public class EntityServiceFileVelocityCreator extends EntityJavaFileVelocityCreatorHelper implements
		MDAFileCreator<EntityModel> {
	private final String DEFAULT_SERVICE_TEMPLATE_PATH = "/javatemplate/javaBizService.mdatemplate";
	private final String SERVICE_TEMPLATE_PATH = "service_template";
	private final String DEFAULT_SERVICE_INTERFACE_TEMPLATE_PATH = "/javatemplate/javaBizServiceInterface.mdatemplate";
	private final String SERVICE_INTERFACE_TEMPLATE_PATH = "service_interface_template";
	private final String DEFAULT_SERVICE_XML_TEMPLATE_PATH = "/javatemplate/javaBizServiceXml.mdatemplate";
	private final String SERVICE_XML_TEMPLATE_PATH = "service_xml_template";
	private static Logger logger = LoggerFactory
			.getLogger(EntityLogicFileVelocityCreator.class);

	private void createServiceInterface(EntityModel model, BeanDetial beanDetial,
			FileUtil fileUtil){
		try {
			// 写service interface文件
			String javaContent = ModelTransUtil.parseFile(context,
					templateMap.get(SERVICE_INTERFACE_TEMPLATE_PATH));
			fileUtil.writeJavaFile((String) context
					.get(JavaFileCreatorHelper.SERVICE_INTERFACE_PACKAGE_NAME),
					(String) context
							.get(JavaFileCreatorHelper.SERVICE_INTERFACE_NAME),
					javaContent);
		} catch (Exception e) {
			logger.errorMessage(
					"模型[package:{0},name:{1}]生成java serviceinterface时出错",
					e,
					context.get(JavaFileCreatorHelper.SERVICE_INTERFACE_PACKAGE_NAME),
					context.get(JavaFileCreatorHelper.SERVICE_INTERFACE_NAME));
		}
	}
	
	private void createServiceImpl(EntityModel model, BeanDetial beanDetial,
			FileUtil fileUtil){
		try {
			// 写service文件
			String javaContent = ModelTransUtil.parseFile(context,
					templateMap.get(SERVICE_TEMPLATE_PATH));
			fileUtil.writeJavaFile(
					(String) context.get(JavaFileCreatorHelper.SERVICE_PACKAGE_NAME),
					(String) context.get(JavaFileCreatorHelper.SERVICE_NAME),
					javaContent);
		} catch (Exception e) {
			logger.errorMessage("模型[package:{0},name:{1}]生成java service时出错", e,
					context.get(JavaFileCreatorHelper.SERVICE_PACKAGE_NAME),
					context.get(JavaFileCreatorHelper.SERVICE_NAME));
		}

	}

	private void createServiceXml(EntityModel model,BeanDetial beanDetial, FileUtil fileUtil) {
		try {
			String serviceConent = ModelTransUtil.parseFile(context,
					templateMap.get(SERVICE_XML_TEMPLATE_PATH));
			// 写service文件
			fileUtil.writeServiceFile(
					(String) context.get(JavaFileCreatorHelper.SERVICE_INTERFACE_PACKAGE_NAME),
					(String) context.get(JavaFileCreatorHelper.SERVICE_INTERFACE_NAME),
					serviceConent);

		} catch (Exception e) {
			logger.errorMessage(
					"模型[package:{0},name:{1}]生成javadao的Service配置文件时出错", e,
					context.get(JavaFileCreatorHelper.SERVICE_INTERFACE_PACKAGE_NAME),
					context.get(JavaFileCreatorHelper.SERVICE_INTERFACE_NAME));
		}
	}
	
	protected void initTemplate() {
		checkTemplate(SERVICE_TEMPLATE_PATH, DEFAULT_SERVICE_TEMPLATE_PATH);
		checkTemplate(SERVICE_XML_TEMPLATE_PATH, DEFAULT_SERVICE_XML_TEMPLATE_PATH);
		checkTemplate(SERVICE_INTERFACE_TEMPLATE_PATH,
				DEFAULT_SERVICE_INTERFACE_TEMPLATE_PATH);
	}

	protected void doCreateFile(EntityModel model, BeanDetial beanDetial,
			FileUtil fileUtil) {
		createServiceInterface(model,beanDetial,fileUtil);
		createServiceImpl(model, beanDetial, fileUtil);
		createServiceXml(model, beanDetial, fileUtil);
	}


}
