/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.mda.springfile;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.List;
import java.util.Map;

import org.tinygroup.exception.TinySysRuntimeException;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;
import org.tinygroup.parser.filter.NameFilter;
import org.tinygroup.xmlparser.XmlDocument;
import org.tinygroup.xmlparser.formatter.XmlFormater;
import org.tinygroup.xmlparser.node.XmlNode;
import org.tinygroup.xmlparser.parser.XmlStringParser;

/**
 * spring文件生成器
 * @author renhui
 *
 */
public class SpringDaoFileCreator {
	private static final String SPRING_TEMPLATE_FILE_NAME = "springtemplate.springbeans.xml";
	private static Logger logger = LoggerFactory.getLogger(SpringDaoFileCreator.class);
	public void writeSpringFile(String resourceDir,String targetFileDir,
			String springBeanId,String beanClassName,Map<String,String> propertys) {
		String fileName = SPRING_TEMPLATE_FILE_NAME;
		String filePath = String.format("%s/%s", targetFileDir,fileName);
		logger.logMessage(LogLevel.INFO, "开始创建文件，包:{0},文件名:{1}", targetFileDir,
				fileName);
	
		XmlStringParser parser = new XmlStringParser();
		try {
			File springFile = new File(filePath);
			if (!springFile.exists()) {
				
				String templateFilePath = String.format("%s/%s", resourceDir,fileName);
				springFile = new File(templateFilePath);
				if (!springFile.exists()) {
					logger.logMessage(LogLevel.ERROR, "找不到spring模板配置文件：{0}",
							filePath);
					throw new TinySysRuntimeException("找不到spring模板配置文件");
				}
				
				createFile(filePath);
			}
			InputStream stream = new FileInputStream(springFile);
			XmlDocument document = parser.parse(readStreamToString(stream));
			NameFilter<XmlNode> filter = new NameFilter<XmlNode>(
					document.getRoot());
			List<XmlNode> nodes = filter.findNodeList("bean");
			if (!hasNodeExist(springBeanId, beanClassName, nodes)) {
				newXmlNode(springBeanId, beanClassName, document.getRoot(),propertys);
			}
			// OutputStream out=new BufferedWriter(new OutputStreamWriter())
			XmlFormater f = new XmlFormater();
			FileOutputStream out = new FileOutputStream(filePath);
			out.write("<?xml  version=\"1.0\" encoding=\"UTF-8\"?>\n".getBytes());
			f.format(document.getRoot(), out);
		} catch (IOException e) {
			logger.errorMessage( "创建文件时出错，文件名:{0}", e,filePath);
		}
		logger.logMessage(LogLevel.INFO, "创建文件完成，包:{0},文件名:{1}", targetFileDir,
				fileName);
	}
	
	private void createFile(String filePath) throws IOException{
		File f = new File(filePath);
		f.getParentFile().mkdirs();
		f.createNewFile();
	}
	
	/**
	 * 通过流解析xml文档
	 * 
	 * @param stream
	 * @return
	 * @throws IOException
	 */
	private String readStreamToString(InputStream stream) throws IOException {
		BufferedReader in = new BufferedReader(new InputStreamReader(stream));
		StringBuffer buffer = new StringBuffer();
		String line = "";
		try {
			while ((line = in.readLine()) != null) {
				buffer.append(line);
				buffer.append("\r\n");
			}
		} finally {
			in.close();
		}
		return buffer.toString();
	}
	
	/**
	 * 新建bean节点
	 * 
	 * @param springDaoId
	 * @param daoClassName
	 */
	private void newXmlNode(String springDaoId, String daoClassName,
			XmlNode root,Map<String,String> propertys) {
		XmlNode newNode = new XmlNode("bean");
		newNode.setAttribute("id", springDaoId);
		newNode.setAttribute("class", daoClassName);
		if(propertys!=null){
			for(String name:propertys.keySet()){
				XmlNode property = new XmlNode("property");
				property.setAttribute("name", name);
				property.setAttribute("ref", propertys.get(name));
				newNode.addNode(property);
			}
		}
		root.addNode(newNode);
	}

	private boolean hasNodeExist(String springDaoId, String daoClassName,
			List<XmlNode> nodes) {
		if (nodes != null && nodes.size() > 0) {
			for (XmlNode xmlNode : nodes) {
				String id = xmlNode.getAttribute("id");
				if (id.equals(springDaoId)) {
					xmlNode.setAttribute("class", daoClassName);
					return true;
				}
			}
		}

		return false;
	}
	
}
