/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.mda.util;

import org.tinygroup.commons.namestrategy.NameStrategy;
import org.tinygroup.commons.namestrategy.impl.CamelCaseStrategy;
import org.tinygroup.mda.config.entity.EntityModel;
import org.tinygroup.mda.config.view.ViewModel;
import org.tinygroup.mda.javabean.BeanDetial;

public class MDANameUtil {
	public static String getBeanName(String modelName) {
		String beanName = modelName.substring(0, 1).toUpperCase()
				+ modelName.substring(1);
		return beanName;
	}
	
	public static String getBeanInsName(String modelName) {
		String beanName = modelName.substring(0, 1).toLowerCase()
				+ modelName.substring(1);
		return beanName;
	}
	
	public static String getDaoBeanId(String modelName) {
		String springDaoId = getBeanInsName(modelName) + "Dao";;
		return springDaoId;
	}
	public static String getLogicBeanId(String modelName) {
		String springDaoId = getBeanInsName(modelName) + "Logic";;
		return springDaoId;
	}
	public static String getBizServiceBeanId(String modelName) {
		String springDaoId = getBeanInsName(modelName) + "Service";;
		return springDaoId;
	}
	public static String getSrpingPackage(String modelPackage){
		if(isNull(modelPackage))
			return "spring";
		return modelPackage+".spring";
	}
	
	
	public static String getDaoName(String modelName) {
		String daoName = getBeanName(modelName) + "Dao";;
		return daoName;
	}
	public static String getDaoPackage(String modelPackage){
		if(isNull(modelPackage))
			return "dao";
		return modelPackage+".dao";
	}
	public static String getServiceName(String modelName) {
		String serviceName = getBeanName(modelName) + "Service";;
		return serviceName;
	}
	public static String getServicePackage(String modelPackage){
		if(isNull(modelPackage))
			return "service.impl";
		return modelPackage+".service.impl";
	}
	public static String getServiceInterfaceName(String modelName) {
		String serviceName = getBeanName(modelName) + "ServiceInterface";;
		return serviceName;
	}
	public static String getServiceInterfacePackage(String modelPackage){
		if(isNull(modelPackage))
			return "service";
		return modelPackage+".service";
	}
	public static String getBeanFullName(BeanDetial beanDetial){
		return beanDetial.getPackageName()+".pojo"+"."+beanDetial.getName();
	}
	
	public static String getLogicName(String modelName) {
		String logicName = getBeanName(modelName) + "Logic";;
		return logicName;
	}
	public static String getLogicPackage(String modelPackage){
		if(isNull(modelPackage))
			return "logic.impl";
		return modelPackage+".logic.impl";
	}
	public static String getLogicInterfaceName(String modelName) {
		String logicName = getBeanName(modelName) + "LogicInterface";;
		return logicName;
	}
	public static String getLogicInterfacePackage(String modelPackage){
		if(isNull(modelPackage))
			return "logic";
		return modelPackage+".logic";
	}
	public static String getTableName(EntityModel model,String pre){
		if(pre==null||"".equals(pre)){
			return getDBName( model.getName() );
		}else{
			return getDBName( pre+"_"+model.getName() );
		}
	}
	
//	public static String getTableName(String name){
//		return getDBName( name );
//	}
	
	public static String getTableId(EntityModel model){
		return model.getUuid();
	}
	
	public static String getViewName(ViewModel model,String pre){
		if(pre==null||"".equals(pre)){
			return getDBName( model.getName() );
		}else{
			return getDBName( pre+"_"+model.getName() );
		}
	}
	public static String getViewId(ViewModel model){
		return model.getUuid();
	}
	
	
	public static NameStrategy getNameStrategy(){
		return new CamelCaseStrategy();
	}
	public static String getMDAName(String name){
		return getNameStrategy().getPropertyName(name);
	}
	public static String getDBName(String propertyName){
		return getNameStrategy().getFieldName(propertyName);
	}
	public static String getPagePackageName(EntityModel model){
		String postPackageName = String.format("%s.%s", model.getName(),"page");
		if(isNull(model.getPackageName())){
			return postPackageName;
		}
		return String.format("%s.%s", model.getPackageName(),postPackageName);
	}
	public static String getFlowPackageName(EntityModel model){
		String postPackageName = String.format("%s.%s", model.getName(),"pageflow");
		if(isNull(model.getPackageName())){
			return postPackageName;
		}
		return String.format("%s.%s", model.getPackageName(),postPackageName);	
	}
	/**
	 * 获取视图/操作对应的页面文件路径(视图和操作的name不允许相同)
	 * @param name  操作/视图 name
	 * @return
	 */
	public static String getPageFileName(String name){
		String fileName = String.format("%s.page",name);
		return fileName;
	}
//	public static String getPageViewFileName(View view){
//		String fileName = String.format("%s.page",view.getName());
//		return fileName;
//	}

//	public static  String getFlowId(EntityModel model, Operation op) {
//		return "flow" + model.getName() + op.getName();
//	}
//	public static  String getFlowId(EntityModel model, View view) {
//		return "flow" + model.getName() + view.getName();
//	}
//	public static  String getFlowId(EntityModel model, View view, String string) {
//		return "flow" + model.getName() + view.getName()+string;
//	}
//	public static  String getFlowId(EntityModel model) {
//		return "flow" + model.getName() + "_DefaultQuery";
//	}
	public static String getFlowId(String modelName, String id, String string){
		return "flow" + modelName + id + string;
	}
	public static String getFlowId(String modelName, String id){
		return "flow" + modelName + id ;
	}
	public static  String getFlowId(String modelName) {
		return "flow" + modelName + "_DefaultQuery";
	}
	
	/**
	 * 获取操作/视图对应的page地址(视图和操作的name不允许相同)
	 * 
	 * @param model
	 * @param name 操作/视图的name
	 * @return
	 */
	public static String getPagePath(EntityModel model, String name) {
		String pagePackageName = MDANameUtil.getPagePackageName(model);
		pagePackageName = pagePackageName.replace(".", "/");
//		String pageFileName = MDANameUtil.getPageFileName(op.getName());
		String pageFileName = MDANameUtil.getPageFileName(name);
		String pagePath = String
				.format("/%s/%s", pagePackageName, pageFileName);
		return pagePath;
	}
//	public static   String getPagePath(EntityModel model, View view) {
//		String pagePackageName = MDANameUtil.getPagePackageName(model);
//		pagePackageName = pagePackageName.replace(".", "/");
//		String pageFileName = MDANameUtil.getPageFileName(view.getName());
//		String pagePath = String
//				.format("/%s/%s", pagePackageName, pageFileName);
//		return pagePath;
//	}
	
	private static boolean isNull(String packageName){
		if(packageName==null||"".equals(packageName))
			return true;
		return false;
	}
}
